@@ -1,3 +1,5 @@
+use std::sync::{atomic::AtomicBool, Arc};
+
 use git_features::progress::{self, Progress};
 use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
 use git_object::{
@@ -7,7 +9,6 @@ use git_object::{
 };
 
 use crate::index;
-use std::{sync::atomic::AtomicBool, sync::Arc};
 
 /// Returned by [`index::File::verify_checksum()`]
 #[derive(thiserror::Error, Debug)]
