@@ -1,8 +1,15 @@
-use crate::{data::EntryRange, tree::traverse::Context, tree::traverse::Error};
-use git_features::progress::{unit, Progress};
-use git_features::zlib;
 use std::{cell::RefCell, collections::BTreeMap};
 
+use git_features::{
+    progress::{unit, Progress},
+    zlib,
+};
+
+use crate::{
+    data::EntryRange,
+    tree::traverse::{Context, Error},
+};
+
 pub(crate) fn deltas<T, F, P, MBFN, S, E>(
     nodes: crate::tree::Chunk<'_, T>,
     (bytes_buf, ref mut progress, state): &mut (Vec<u8>, P, S),
